==> org-lsst-ccs-config-definition-5.3.13-sources.jar: org/lsst/ccs/config/WriterProvider.java <==
package org.lsst.ccs.config;


import java.io.IOException;
import java.io.PrintWriter;
import java.util.Properties;
import java.util.Set;

/**
 * Generic interface for writing, reading and finding properties files against 
 * a pattern.
 */
public abstract class WriterProvider {
    
    
    public synchronized static WriterProvider getInstance() {
        String className = null;
        //First check if System property org.lsst.ccs.config.WriterProvider has been set
        className = System.getProperty("org.lsst.ccs.config.WriterProvider", "");
        //If className is still not specified, then set it to:
        //  org.lsst.ccs.config.InMemoryFileWriterProvider if we are running tests
        //  org.lsst.ccs.config.FileWriterProvider if we are not running tests.
        if (className == null || className.isEmpty()) {
            className = System.getProperty("org.lsst.ccs.testcontext", "false").equals("true")
                    ? "org.lsst.ccs.config.InMemoryFileWriterProvider"
                    : "org.lsst.ccs.config.FileWriterProvider";
        }

        try {
            return (WriterProvider) Class.forName(className).newInstance();
        } catch (ClassNotFoundException cnfe) {
            throw new RuntimeException("Could not find class definition for WriterProvider " + className, cnfe);
        } catch (InstantiationException | IllegalAccessException ie) {
            throw new RuntimeException("Could not create instance of WriterProvider " + className, ie);
        }
    }
    
    
    public abstract PrintWriter getPrintWriter(String fileName) throws IOException;

    /**
     * @param fileName
     * @return null if no file matching filename has been found.
     * @throws IOException 
     */
    public abstract Properties getProperties(String fileName) throws IOException;
    
    abstract Set<String> findMatchingPropertiesFiles(String pattern);

    abstract String locateFile(String fileName);
}

==> org-lsst-ccs-config-definition-5.4.5-sources.jar: org/lsst/ccs/config/WriterProvider.java <==
package org.lsst.ccs.config;


import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.Properties;
import java.util.Set;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.lsst.ccs.bootstrap.BootstrapResourceUtils;

/**
 * Generic interface for writing, reading and finding properties files against 
 * a pattern.
 */
public abstract class WriterProvider {
    
    
    public synchronized static WriterProvider getInstance() {
        String className = null;
        //First check if System property org.lsst.ccs.config.WriterProvider has been set
        className = System.getProperty("org.lsst.ccs.config.WriterProvider", "");
        //If className is still not specified, then set it to:
        //  org.lsst.ccs.config.InMemoryFileWriterProvider if we are running tests
        //  org.lsst.ccs.config.FileWriterProvider if we are not running tests.
        if (className == null || className.isEmpty()) {
            className = System.getProperty("org.lsst.ccs.testcontext", "false").equals("true")
                    ? "org.lsst.ccs.config.InMemoryFileWriterProvider"
                    : "org.lsst.ccs.config.FileWriterProvider";
        }

        try {
            return (WriterProvider) Class.forName(className).newInstance();
        } catch (ClassNotFoundException cnfe) {
            throw new RuntimeException("Could not find class definition for WriterProvider " + className, cnfe);
        } catch (InstantiationException | IllegalAccessException ie) {
            throw new RuntimeException("Could not create instance of WriterProvider " + className, ie);
        }
    }
    
    
    public abstract PrintWriter getPrintWriter(String fileName) throws IOException;

    /**
     * @param fileName
     * @return null if no file matching filename has been found.
     * @throws IOException 
     */
    public Properties getProperties(String fileName) throws IOException {
        Properties configProps = new Properties();
        InputStream propsIs = getInputStream(fileName);
        if (propsIs == null) { // The resource could not be found
            return null;
        }        
        LOG.log(Level.INFO, "Found configuration file : {0}", BootstrapResourceUtils.getResourceURL(fileName));
        configProps.load(propsIs);
        return configProps;        
    }

    private static final Logger LOG = Logger.getLogger(WriterProvider.class.getName());
    
    /**
     * @param fileName
     * @return null if no file matching filename has been found.
     * @throws IOException 
     */
    public abstract InputStream getInputStream(String fileName) throws IOException;

    abstract Set<String> findMatchingPropertiesFiles(String pattern);

    abstract String locateFile(String fileName);
}
